@@ -1,53 +1,25 @@
+#!/usr/bin/env python
 # -*- coding: utf-8 -*-
-
+#
+# Copyright (C) 2009 Bernardo Heynemann <heynemann@gmail.com>
+# Copyright (C) 2009 Gabriel Falcão <gabriel@nacaolivre.org>
+#
 # Licensed under the Open Software License ("OSL") v. 3.0 (the "License");
 # you may not use this file except in compliance with the License.
 # You may obtain a copy of the License at
-
+#
 #     http://www.opensource.org/licenses/osl-3.0.php
-
+#
 # Unless required by applicable law or agreed to in writing, software
 # distributed under the License is distributed on an "AS IS" BASIS,
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-import time
-import urllib2
-
 class BrowserDriver(object):
-    __browser__ = ""
-
-    def __init__(self, browser_to_run, tests_dir):
-        self.__browser__ = browser_to_run
-        self.root_dir = tests_dir
-
     def resolve_element_key(self, context, element_type, element_key):
         raise NotImplementedError
 
-    def __wait_for_server_to_start(self):
-        server_started = False
-        while server_started == False:
-            server_started = self.__is_server_started()
-            time.sleep(2)
-
-    def __is_server_started(self):
-        timeout = urllib2.socket.getdefaulttimeout()
-        try:
-            urllib2.socket.setdefaulttimeout(5)
-            url = "http://%s:%s/" % (self.__host__, self.__port__)
-            request = urllib2.urlopen(url)
-            server_started = True
-            request.close()
-        except IOError, e:
-            server_started = False
-
-        urllib2.socket.setdefaulttimeout(timeout)
-        return server_started
-
-    def start(self):
-        pass
-
     def get_xpath_count(self, xpath):
         raise NotImplementedError
 
@@ -55,7 +27,7 @@ class BrowserDriver(object):
         """gets the css class name"""
         raise NotImplementedError
 
-    def start_test(self, url = "http://www.someurl.com"):
+    def start_test(self, url=None):
         raise NotImplementedError
 
     def page_open(self, url):
@@ -67,13 +39,16 @@ class BrowserDriver(object):
     def type(self, input_selector, text):
         raise NotImplementedError
 
+    def type_keys(self, input_selector, text):
+        raise NotImplementedError
+
     def click_element(self, element_selector):
         raise NotImplementedError
 
     def is_element_visible(self, element_selector):
         raise NotImplementedError
 
-    def wait_for_page(self, timeout = 20000):
+    def wait_for_page(self, timeout=0):
         raise NotImplementedError
 
     def get_title(self):
@@ -106,6 +81,9 @@ class BrowserDriver(object):
     def get_element_markup(self, element_selector):
         raise NotImplementedError
 
+    def get_html_source(self):
+        raise NotImplementedError
+
     def select_option_by_index(self, element_selector, index):
         raise NotImplementedError
 
@@ -148,9 +126,18 @@ class BrowserDriver(object):
     def stop_test(self):
         raise NotImplementedError
 
-    def stop(self):
-        pass
+    def exec_js(self, js):
+        raise NotImplementedError
 
     def __get_attribute_value(self, element, attribute):
         raise NotImplementedError
 
+    def radio_is_checked(self, radio_selector):
+        raise NotImplementedError
+
+    def radio_check(self, radio_selector):
+        raise NotImplementedError
+
+    def radio_uncheck(self, radio_selector):
+        raise NotImplementedError
+
